#!/usr/bin/python3

# Command line focus control by image defocus in pixels or arcseconds

# Moore Observatory focuser control
# Copyright (c) 2012-2018 John Kielkopf
# kielkopf@louisville.edu

# Date: May 6, 2018
# Version: 2.0

# This file is part of PyFocus


#Basic imports

import sys


motor_count = 0
focus_position = 0
focus_pix = 0
focus_arcsec = 0

# Set to true for diagnostic messages

diagnostics = False

#
# Change these for specific telescope/focuser/motor combination
#

# Location of status file

#focus_status_file = "/usr/local/observatory/status/telfocus"

focus_status_file = './telfocus'

# Focuser parameters

# For Phidgets motor on the CDK20N/S telescopes
# Motor RPM at 100% duty cycle: 4000.
# Motor RPM speed factor: 0.5 estimated
# Motor shaft encoder counts/turn: 360.
# Motor gear reduction: 139. + 184./1221. = 139.150696151
# Focuser screw pitch: 32 tpi
# Focuser translation scale: 793.75 microns / shaft revolution
# Motor counts per micron focuser motion: 63.111
# Focal ratio: f/6.8
# Pixel size: 9 microns
# Secondary magnification: 1.0 (needed if focuser moves secondary)

# Set motor and focuser parameters

counts_per_revolution = 360.
revolutions_per_second = 0.5*4000./60.
counts_per_second = counts_per_revolution * revolutions_per_second
counts_per_micron = 63.11
delta_count_max = 1000.*counts_per_micron

# Set telescope parameters

f_ratio = 6.8
pixel_size = 9.0
arcsecond_per_pixel = 0.53

# Set image scale for pixel and arcseond defocus units

counts_per_pixel =  pixel_size*f_ratio*counts_per_micron
counts_per_arcsec = counts_per_pixel/arcsecond_per_pixel


#
# End of user installation parameters
#


# Check that the user supplied a change in pixels


if len(sys.argv) != 1:
  print (" ")
  sys.exit("Usage: focus_get.py")

  
# Look up the saved last position of the focuser in microns if any
# Assign current encoder count to match or else set to zero

try: 
  focus_status_fp = open(focus_status_file,'r')
  focus_str = focus_status_fp.read(40)
  focus_status_fp.close()
  motor_count = float(focus_str)
except:
  print (focus_status_file+" is missing or empty")
  print ("Setting focus position to zero")
  print (" ")
  motor_count = 0.

# Set the focus position from the motor count

focus_position = motor_count/counts_per_micron


# Set image  focus_pix in pixels and  focus_arcsec in arcseconds  

focus_pix = abs(motor_count)/counts_per_pixel
focus_arcsec = abs(motor_count)/counts_per_arcsec

print ("Position (microns): ", format(focus_position,'7.0f') )
print ("Image (pix): ", format(focus_pix,'7.0f') )
print ("Sky (arcsec): ", format(focus_arcsec,'7.1f') )

exit(0)
