#!/usr/bin/python

# Moore Observatory focuser control
# Copyright (c) 2012 John Kielkopf
# kielkopf@louisville.edu

# Date: September 3, 2014
# Version: 1.3

# This file is part of PyFocus

# Credit: Phidgets code downloaded on July 5, 2012
# Copyright: 2010 Phidgets Inc.
# License: Creative Commons Attribution 2.5 Canada License
# Author: Adam Stelmack
# Date: May 16, 2010


#Basic imports

from ctypes import *
import sys

#Phidget imports

from Phidgets.PhidgetException import PhidgetErrorCodes, PhidgetException
from Phidgets.Events.Events import AttachEventArgs, DetachEventArgs, ErrorEventArgs, CurrentChangeEventArgs, InputChangeEventArgs, VelocityChangeEventArgs
from Phidgets.Devices.MotorControl import MotorControl

#Sleeping thread imports

from time import sleep


if len(sys.argv) > 1:    
  sys.exit("Usage: temperature_read.py")


# Temperature sensors are read through the focuser motor control device

# Create a motor control object

try:
  motorControl = MotorControl()
except RuntimeError as e:
  print("Temperature reading runtime exception: %s" % e.details)
  print("Exiting ...")
  exit(1)

# Information

def displayDeviceInfo():
  print("|------------|----------------------------------|--------------|------------|")
  print("|- Attached -|-              Type              -|- Serial No. -|-  Version -|")
  print("|------------|----------------------------------|--------------|------------|")
  print("|- %8s -|- %30s -|- %10d -|- %8d -|" % (motorControl.isAttached(), motorControl.getDeviceName(), motorControl.getSerialNum(), motorControl.getDeviceVersion()))
  print("|------------|----------------------------------|--------------|------------|")

#Event Handler Callback Functions

def motorControlAttached(e):
  attached = e.device

def motorControlDetached(e):
  detached = e.device

def motorControlError(e):
  try:
    source = e.device
    print("Motor Control %i: Phidget Error %i: %s" % (source.getSerialNum(), e.eCode, e.description))
  except PhidgetException as e:
    print("Phidget exception %i: %s" % (e.code, e.details))

def motorControlCurrentChanged(e):
  source = e.device
  print("Motor Control %i: Motor %i Current Draw: %f" % (source.getSerialNum(), e.index, e.current))

def motorControlInputChanged(e):
  source = e.device
  print("Motor Control %i: Input %i State: %s" % (source.getSerialNum(), e.index, e.state))

def motorControlVelocityChanged(e):
  source = e.device
  print("Motor Control %i: Motor %i Current Velocity: %f" % (source.getSerialNum(), e.index, e.velocity))


try:
  motorControl.setOnAttachHandler(motorControlAttached)
  motorControl.setOnDetachHandler(motorControlDetached)
  motorControl.setOnErrorhandler(motorControlError)
except PhidgetException as e:
  print("Temperature reading Phidget handler exception %i: %s" % (e.code, e.details))
  print("Exiting ...")
  exit(1)

try:
  motorControl.openPhidget()
except PhidgetException as e:
  print("Temperature reading Phidget open exception %i: %s" % (e.code, e.details))
  print("Exiting ...")
  exit(1)

try:
  motorControl.waitForAttach(10000)
except PhidgetException as e:
  print("Temperature reading Phidget attachment exception %i: %s" % (e.code, e.details))
  try:
    motorControl.closePhidget()
  except PhidgetException as e:
    print("Temperature reading Phidget close exception %i: %s" % (e.code, e.details))
    print("Exiting ...")
    exit(1)
  print("Exiting ...")
  exit(1)


# Read temperatures

sensor0 = motorControl.getSensorValue(0)
temperature0 = (float(sensor0)*0.2222) - 61.111
print ("OTA temperature: " '{0:.2f}'.format(temperature0))

sensor1 = motorControl.getSensorValue(1)
temperature1 = (float(sensor1)*0.2222) - 61.111
print ("Mirror temperature: " '{0:.2f}'.format(temperature1))

temperaturestatus = open('/usr/local/observatory/status/teltemperature','w')
temperaturestatus.write ("%f \n" % (temperature0))
temperaturestatus.write ("%f \n" % (temperature1))
temperaturestatus.close()

   

try:
  motorControl.closePhidget()
except PhidgetException as e:
  print("Temperature reading Phidget close exception %i: %s" % (e.code, e.details))
  print("Exiting ...")
  exit(1)

exit(0)
